@@ -13,18 +13,16 @@
  */
 
 #include "k3bgrowisofshandler.h"
-
 #include "k3bjob.h"
 #include "k3bcore.h"
 #include "k3bglobalsettings.h"
 #include "k3bdevice.h"
 #include "k3bdevicehandler.h"
+#include "k3b_i18n.h"
 
-#include <klocale.h>
-#include <kglobal.h>
-#include <kdebug.h>
-
-#include <qtimer.h>
+#include <QtCore/QDebug>
+#include <QtCore/QLocale>
+#include <QtCore/QTimer>
 
 #include <errno.h>
 #include <string.h>
@@ -141,11 +139,11 @@ void K3b::GrowisofsHandler::handleLine( const QString& line )
     }
     else if( line.contains( "updating RMA" ) ) {
         emit newSubTask( i18n("Updating RMA") );
-        emit infoMessage( i18n("Updating RMA") + "...", K3b::Job::MessageInfo );
+        emit infoMessage( i18n("Updating RMA..."), K3b::Job::MessageInfo );
     }
     else if( line.contains( "closing session" ) ) {
         emit newSubTask( i18n("Closing Session") );
-        emit infoMessage( i18n("Closing Session") + "...", K3b::Job::MessageInfo );
+        emit infoMessage( i18n("Closing Session..."), K3b::Job::MessageInfo );
     }
     else if( line.contains( "writing lead-out" ) ) {
         emit newSubTask( i18n("Writing Lead-out") );
@@ -155,7 +153,7 @@ void K3b::GrowisofsHandler::handleLine( const QString& line )
         emit infoMessage( i18n("Removing reference to lead-out."), K3b::Job::MessageInfo );
     }
     else if( line.contains( "copying volume descriptor" ) ) {
-        emit infoMessage( i18n("Modifying ISO9660 volume descriptor"), K3b::Job::MessageInfo );
+        emit infoMessage( i18n("Modifying ISO 9660 volume descriptor"), K3b::Job::MessageInfo );
     }
     else if( line.contains( "FEATURE 21h is not on" ) ) {
         if( !m_dao ) {
@@ -177,9 +175,9 @@ void K3b::GrowisofsHandler::handleLine( const QString& line )
         if( ok )
             emit infoMessage( i18n("Writing speed: %1 KB/s (%2x)",
                                    int( speed * double( Device::SPEED_FACTOR_DVD ) )
-                                   ,KGlobal::locale()->formatNumber(speed)), K3b::Job::MessageInfo );
+                                   ,QLocale::system().toString(speed)), K3b::Job::MessageInfo );
         else
-            kDebug() << "(K3b::GrowisofsHandler) parsing error: '" << line.mid( pos, endPos-pos ) << "'";
+            qDebug() << "(K3b::GrowisofsHandler) parsing error: '" << line.mid( pos, endPos-pos ) << "'";
     }
     else if( (pos = line.indexOf( "RBU" )) > 0 ) {
 
@@ -213,11 +211,11 @@ void K3b::GrowisofsHandler::handleLine( const QString& line )
             }
         }
         else
-            kDebug() << "(K3b::GrowisofsHandler) failed to parse ring buffer fill from '" << line.mid( pos, endPos-pos ) << "'";
+            qDebug() << "(K3b::GrowisofsHandler) failed to parse ring buffer fill from '" << line.mid( pos, endPos-pos ) << "'";
     }
 
     else {
-        kDebug() << "(growisofs) " << line;
+        qDebug() << "(growisofs) " << line;
     }
 }
 
@@ -310,8 +308,8 @@ void K3b::GrowisofsHandler::slotCheckBufferStatusDone( K3b::Device::DeviceHandle
         QTimer::singleShot( 500, this, SLOT(slotCheckBufferStatus()) );
     }
     else {
-        kDebug() << "(K3b::GrowisofsHandler) stopping buffer check.";
+        qDebug() << "(K3b::GrowisofsHandler) stopping buffer check.";
     }
 }
 
-#include "k3bgrowisofshandler.moc"
+
